==> org.eclipse.eef.ide.ui.source_1.9.0.201701271010.jar: org/eclipse/eef/ide/ui/internal/Icons.java <==
/*******************************************************************************
 * Copyright (c) 2016 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.eef.ide.ui.internal;

/**
 * The paths of the icons available in this bundle.
 *
 * @author sbegaudeau
 */
public interface Icons {
	/**
	 * Help.
	 */
	String HELP = "icons/full/help.gif"; //$NON-NLS-1$

	/**
	 * Create.
	 */
	String CREATE = "icons/full/create.gif"; //$NON-NLS-1$

	/**
	 * Search.
	 */
	String SEARCH = "icons/full/search.gif"; //$NON-NLS-1$

	/**
	 * Unset.
	 */
	String UNSET = "icons/full/unset.gif"; //$NON-NLS-1$

	/**
	 * Up.
	 */
	String UP = "icons/full/up.gif"; //$NON-NLS-1$

	/**
	 * Down.
	 */
	String DOWN = "icons/full/down.gif"; //$NON-NLS-1$

	/**
	 * Quick fix.
	 */
	String QUICK_FIX = "icons/full/wizban/quick_fix.png"; //$NON-NLS-1$

	/**
	 * Info.
	 */
	String INFO = "icons/full/info.gif"; //$NON-NLS-1$

	/**
	 * Warning.
	 */
	String WARNING = "icons/full/warning.gif"; //$NON-NLS-1$

	/**
	 * Error.
	 */
	String ERROR = "icons/full/error.gif"; //$NON-NLS-1$

	/**
	 * Fix.
	 */
	String FIX = "icons/full/fix.gif"; //$NON-NLS-1$

	/**
	 * Permission Denied.
	 */
	String PERMISSION_DENIED = "icons/full/permission_denied.gif"; //$NON-NLS-1$

	/**
	 * Permission Granted to current user exclusively.
	 */
	String PERMISSION_GRANTED_TO_CURRENT_USER_EXCLUSIVELY = "icons/full/permission_granted_to_current_user_exclusively.gif"; //$NON-NLS-1$
}

==> org.eclipse.eef.ide.ui.source_1.9.2.201712191609.jar: org/eclipse/eef/ide/ui/internal/Icons.java <==
/*******************************************************************************
 * Copyright (c) 2016 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.eef.ide.ui.internal;

/**
 * The paths of the icons available in this bundle.
 *
 * @author sbegaudeau
 */
public interface Icons {
	/**
	 * Help.
	 */
	String HELP = "icons/full/help.gif"; //$NON-NLS-1$

	/**
	 * Create.
	 */
	String CREATE = "icons/full/create.gif"; //$NON-NLS-1$

	/**
	 * Search.
	 */
	String SEARCH = "icons/full/search.gif"; //$NON-NLS-1$

	/**
	 * Unset.
	 */
	String UNSET = "icons/full/unset.gif"; //$NON-NLS-1$

	/**
	 * Up.
	 */
	String UP = "icons/full/up.gif"; //$NON-NLS-1$

	/**
	 * Down.
	 */
	String DOWN = "icons/full/down.gif"; //$NON-NLS-1$

	/**
	 * Quick fix.
	 */
	String QUICK_FIX = "icons/full/wizban/quick_fix.png"; //$NON-NLS-1$

	/**
	 * Info.
	 */
	String INFO = "icons/full/info.gif"; //$NON-NLS-1$

	/**
	 * Warning.
	 */
	String WARNING = "icons/full/warning.gif"; //$NON-NLS-1$

	/**
	 * Error.
	 */
	String ERROR = "icons/full/error.gif"; //$NON-NLS-1$

	/**
	 * Fix.
	 */
	String FIX = "icons/full/fix.gif"; //$NON-NLS-1$

	/**
	 * Permission Denied.
	 */
	String PERMISSION_DENIED = "icons/full/permission_denied.gif"; //$NON-NLS-1$

	/**
	 * Permission Granted to current user exclusively.
	 */
	String PERMISSION_GRANTED_TO_CURRENT_USER_EXCLUSIVELY = "icons/full/permission_granted_to_current_user_exclusively.gif"; //$NON-NLS-1$

	/**
	 * Permission No Write.
	 */
	String PERMISSION_NO_WRITE = "icons/full/permission_no_write.gif"; //$NON-NLS-1$
}
